# the-python-bay

Python library for searching thepiratebay.org

## Install

    pip install the-python-bay

## Usage

```
from the_python_bay import tpb

tpb.search("ubuntu")
```

This will return the results in a JSON format.